Added bridgin support for GSM and SIP
[lcr.git] / message.h
index 63abc65..6330654 100644 (file)
--- a/message.h
+++ b/message.h
@@ -9,8 +9,6 @@
 **                                                                           **
 \*****************************************************************************/ 
 
-#define ISDN_TRANSMIT  256 // samples
-
 enum { /* interface types */
        INFO_ITYPE_ISDN, /* call from external */
        INFO_ITYPE_ISDN_EXTENSION, /* call from internal extension */
@@ -124,7 +122,6 @@ enum { /* diversion types */
 enum { /* isdnsignal */
        mISDNSIGNAL_VOLUME,             /* change volume */
        mISDNSIGNAL_CONF,               /* joint/split conference */
-       mISDNSIGNAL_JOINDATA,           /* data required by join instance */
        mISDNSIGNAL_ECHO,               /* enable/disable echoe */
        mISDNSIGNAL_DELAY,              /* use delay or adaptive jitter */
 };
@@ -151,6 +148,13 @@ enum {
        B_MODE_HDLC,            /* hdlc data mode */
 };
 
+/* rtp-info structure */
+struct rtp_info {
+       int payload_type;
+       unsigned int ip;
+       unsigned short port;
+};
+
 /* call-info structure CALLER */
 struct caller_info {
        char id[32];                    /* id of caller (user number) */
@@ -194,6 +198,7 @@ struct connect_info {
        int screen;                     /* who provided the number */
        char display[84];               /* display information */
        char imsi[16];                  /* IMSI for gsm terminated calls */
+       struct rtp_info rtpinfo;        /* info about RTP peer */
 };
 
 /* call-info structure DISCONNECT */
@@ -201,6 +206,7 @@ struct disconnect_info {
        int cause;                      /* reason for disconnect */
        int location;                   /* disconnect location */
        char display[84];               /* optional display information */
+       int force;                      /* special flag to release imediately */
 };
 
 /* call-info structure REDIR */
@@ -238,6 +244,13 @@ struct notify_info {
        int local;                      /* if set, endpoints gets information about audio channel (open/close) */
 };
 
+/* call-info structure PROGRESS */
+struct progress_info {
+       int progress;                   /* progress indicator */
+       int location;                   /* progress location */
+       struct rtp_info rtpinfo;        /* info about RTP peer */
+};
+
 /* call-info structure FACILITY */
 struct facility_info {
        char data[256];                 /* data info about facility */
@@ -262,6 +275,8 @@ struct message_setup {
        struct redir_info redirinfo;            /* info on redirection (to the calling user) */
        struct capa_info capainfo;              /* info on l2,l3 capability */
        struct useruser_info useruser;          /* user-user */
+       struct progress_info progress;          /* info on call progress */
+       struct rtp_info rtpinfo;                /* info about RTP peer */
        char context[128];                      /* asterisk context */
 };
 
@@ -271,12 +286,6 @@ struct park_info {
        int len;
 };
 
-/* DATA */
-struct param_data {
-       unsigned char data[ISDN_TRANSMIT]; /* audio/hdlc data */
-       int len; /* audio/hdlc data */
-};
-
 struct param_play {
        char file[512]; /* file name */
        int offset; /* offset to start file at (in seconds) */
@@ -297,7 +306,6 @@ struct param_mISDNsignal {
        int tx_gain;
        int rx_gain;
        int conf;
-       int joindata;
        int tone;
        int echo;
        int delay;
@@ -317,6 +325,7 @@ struct param_hello {
 struct param_bchannel {
        int type; /* BCHANNEL_* */
        unsigned int handle; /* bchannel stack/portid */
+       int isloopback; /* in this case the application behaves like an interface, dsp should not be used */
        int tx_gain, rx_gain;
        char pipeline[256];
        unsigned char crypt[128];
@@ -324,6 +333,11 @@ struct param_bchannel {
        int crypt_type; /* 1 = blowfish */
 };
 
+struct param_newref {
+        int direction; /* who requests a refe? */
+       int mode; /* 0 = direct-mode, 1 = PBX mode */
+};
+
 /* structure of message parameter */
 union parameter {
        struct param_tone tone; /* MESSAGE_TONE */
@@ -333,12 +347,12 @@ union parameter {
        struct connect_info connectinfo; /* CONNECT INFO */
        struct disconnect_info disconnectinfo; /* DISCONNECT INFO */
        struct notify_info notifyinfo; /* some notifications */
+       struct progress_info progressinfo; /* some progress */
        struct facility_info facilityinfo; /* some notifications */
        struct park_info parkinfo; /* MESSAGE_SUSPEND, MESSAGE_RESUME */
        int state; /* MESSAGE_TIMEOUT */
        int knock; /* MESSAGE_KNOCK 0=off !0=on */
        int audiopath; /* MESSAGE_audiopath see RELATION_CHANNEL_* (join.h) */
-       struct param_data data; /* MESSAGE_DATA */
        struct param_play play; /* MESSAGE_VBOX_PLAY */
        int speed; /* MESSAGE_VBOX_PLAY_SPEED */
        struct param_counter counter; /* MESSAGE_TONE_COUNTER */
@@ -347,7 +361,8 @@ union parameter {
        struct param_crypt crypt; /* MESSAGE_CRYPT */
        struct param_hello hello; /* MESSAGE_HELLO */
        struct param_bchannel bchannel; /* MESSAGE_BCHANNEL */
-       int direction; /* MESSAGE_NEWREF */
+       struct param_newref newref; /* MESSAGE_NEWREF */
+       unsigned int bridge_id; /* MESSAGE_BRIDGE */
 };
 
 enum { /* message flow */
@@ -383,16 +398,15 @@ enum { /* messages between entities */
        MESSAGE_DISCONNECT,     /* disconnect with cause */
        MESSAGE_RELEASE,        /* release with cause */
        MESSAGE_TIMEOUT,        /* protocol state has timed out (port->epoint) */
-       MESSAGE_NOTIFY,         /* used to send progress and notify infos */
+       MESSAGE_NOTIFY,         /* used to send notify info */
+       MESSAGE_PROGRESS,       /* used to send progress info */
        MESSAGE_FACILITY,       /* used to facility infos, like aocd */
        MESSAGE_SUSPEND,        /* suspend port */
        MESSAGE_RESUME,         /* resume port */
        MESSAGE_AUDIOPATH,      /* set status of audio path to endpoint (to call, audio is also set) */
-//     MESSAGE_REMOTE_AUDIO,   /* tell remote to set audio status */
        MESSAGE_PATTERN,        /* pattern information tones available */
        MESSAGE_NOPATTERN,      /* pattern information tones unavailable */
        MESSAGE_CRYPT,          /* encryption message */
-       MESSAGE_DATA,           /* audio/hdlc data */
        MESSAGE_VBOX_PLAY,      /* play recorded file */
        MESSAGE_VBOX_PLAY_SPEED,/* change speed of file */
        MESSAGE_VBOX_TONE,      /* set answering VBOX tone */
@@ -401,6 +415,7 @@ enum { /* messages between entities */
        MESSAGE_BCHANNEL,       /* request/assign/remove bchannel */
        MESSAGE_HELLO,          /* hello message for remote application */
        MESSAGE_NEWREF,         /* special message to create and inform ref */
+       MESSAGE_BRIDGE,         /* control port bridge */
 };
 
 #define MESSAGES static const char *messages_txt[] = { \
@@ -419,15 +434,14 @@ enum { /* messages between entities */
        "MESSAGE_RELEASE", \
        "MESSAGE_TIMEOUT", \
        "MESSAGE_NOTIFY", \
+       "MESSAGE_PROGRESS", \
        "MESSAGE_FACILITY", \
        "MESSAGE_SUSPEND", \
        "MESSAGE_RESUME", \
        "MESSAGE_AUDIOPATH", \
-/*     "MESSAGE_REMOTE_AUDIO",*/ \
        "MESSAGE_PATTERN", \
        "MESSAGE_NOPATTERN", \
        "MESSAGE_CRYPT", \
-       "MESSAGE_DATA", \
        "MESSAGE_VBOX_PLAY", \
        "MESSAGE_VBOX_PLAY_SPEED", \
        "MESSAGE_VBOX_TONE", \
@@ -436,14 +450,17 @@ enum { /* messages between entities */
        "MESSAGE_BCHANNEL", \
        "MESSAGE_HELLO", \
        "MESSAGE_NEWREF", \
+       "MESSAGE_BRIDGE", \
 };
 
 
 struct lcr_msg *message_create(int id_from, int id_to, int flow, int type);
-void message_put(struct lcr_msg *message);
+#define message_put(m) _message_put(m, __FILE__, __LINE__)
+void _message_put(struct lcr_msg *message, const char *file, int line);
 struct lcr_msg *message_forward(int id_from, int id_to, int flow, union parameter *param);
 struct lcr_msg *message_get(void);
 void message_free(struct lcr_msg *message);
-
+void init_message(void);
+void cleanup_message(void);